Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(129)

Unified Diff: net/socket/socket_test_util.h

Issue 2351513002: net: rename BoundNetLog to NetLogWithSource (Closed)
Patch Set: REBASE Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/socket/socket_test_util.h
diff --git a/net/socket/socket_test_util.h b/net/socket/socket_test_util.h
index 431b229f9dec05b35902406d74bcf569cb46b9f6..5a13807db878ec6ec1712b85485c3bf36c2970ca 100644
--- a/net/socket/socket_test_util.h
+++ b/net/socket/socket_test_util.h
@@ -544,9 +544,10 @@ class MockClientSocketFactory : public ClientSocketFactory {
class MockClientSocket : public SSLClientSocket {
public:
// The BoundNetLog is needed to test LoadTimingInfo, which uses NetLog IDs as
// unique socket IDs.
- explicit MockClientSocket(const BoundNetLog& net_log);
+ explicit MockClientSocket(const NetLogWithSource& net_log);
// Socket implementation.
int Read(IOBuffer* buf,
@@ -565,7 +566,7 @@ class MockClientSocket : public SSLClientSocket {
bool IsConnectedAndIdle() const override;
int GetPeerAddress(IPEndPoint* address) const override;
int GetLocalAddress(IPEndPoint* address) const override;
- const BoundNetLog& NetLog() const override;
+ const NetLogWithSource& NetLog() const override;
void SetSubresourceSpeculation() override {}
void SetOmniboxSpeculation() override {}
bool WasNpnNegotiated() const override;
@@ -598,7 +599,7 @@ class MockClientSocket : public SSLClientSocket {
// Address of the "remote" peer we're connected to.
IPEndPoint peer_addr_;
- BoundNetLog net_log_;
+ NetLogWithSource net_log_;
private:
base::WeakPtrFactory<MockClientSocket> weak_factory_;
@@ -744,7 +745,7 @@ class MockUDPClientSocket : public DatagramClientSocket, public AsyncSocket {
int GetPeerAddress(IPEndPoint* address) const override;
int GetLocalAddress(IPEndPoint* address) const override;
void UseNonBlockingIO() override;
- const BoundNetLog& NetLog() const override;
+ const NetLogWithSource& NetLog() const override;
// DatagramClientSocket implementation.
int Connect(const IPEndPoint& address) override;
@@ -787,7 +788,7 @@ class MockUDPClientSocket : public DatagramClientSocket, public AsyncSocket {
CompletionCallback pending_read_callback_;
CompletionCallback pending_write_callback_;
- BoundNetLog net_log_;
+ NetLogWithSource net_log_;
base::WeakPtrFactory<MockUDPClientSocket> weak_factory_;
@@ -843,7 +844,7 @@ class ClientSocketPoolTest {
requests_.push_back(base::WrapUnique(request));
int rv = request->handle()->Init(group_name, socket_params, priority,
respect_limits, request->callback(),
- socket_pool, BoundNetLog());
+ socket_pool, NetLogWithSource());
if (rv != ERR_IO_PENDING)
request_order_.push_back(request);
return rv;
@@ -932,7 +933,7 @@ class MockTransportClientSocketPool : public TransportClientSocketPool {
RespectLimits respect_limits,
ClientSocketHandle* handle,
const CompletionCallback& callback,
- const BoundNetLog& net_log) override;
+ const NetLogWithSource& net_log) override;
void CancelRequest(const std::string& group_name,
ClientSocketHandle* handle) override;
@@ -965,7 +966,7 @@ class MockSOCKSClientSocketPool : public SOCKSClientSocketPool {
RespectLimits respect_limits,
ClientSocketHandle* handle,
const CompletionCallback& callback,
- const BoundNetLog& net_log) override;
+ const NetLogWithSource& net_log) override;
void CancelRequest(const std::string& group_name,
ClientSocketHandle* handle) override;
@@ -544,9 +544,10 @@ class MockClientSocketFactory : public ClientSocketFactory {
class MockClientSocket : public SSLClientSocket {
public:
- // The BoundNetLog is needed to test LoadTimingInfo, which uses NetLog IDs as
+ // The NetLogWithSource is needed to test LoadTimingInfo, which uses NetLog
+ // IDs as
// unique socket IDs.

Powered by Google App Engine
This is Rietveld 408576698